@@ -156,11 +156,11 @@ class RabbitMqAgent():
             time.sleep(2)
 
 g_amq = RabbitMqAgent()
+g_amq_broke_config = AMQ_BrokerConfig()
 
 
 if __name__ == '__main__':
-    amq_broke_config = AMQ_BrokerConfig()
-    g_amq.connect_to_broker(amq_broke_config)
+    g_amq.connect_to_broker(g_amq_broke_config)
 
     # img = cv2.imread("nocommand.jpg")
     # g_amq.publish_cv_image("test" , img)
